@@ -24,18 +24,22 @@
  *
  */
 
+#if defined(HAVE_CONFIG_H)
+#include <config_ac.h>
+#endif
+
 #include "libscp_tcp.h"
 
 extern struct log_config *s_log;
 
 /*****************************************************************************/
-int DEFAULT_CC
+int
 scp_tcp_force_recv(int sck, char *data, int len)
 {
     int rcvd;
     int block;
 
-    LOG_DBG("scp_tcp_force_recv()");
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "scp_tcp_force_recv()");
     block = scp_lock_fork_critical_section_start();
 
     while (len > 0)
@@ -72,13 +76,13 @@ scp_tcp_force_recv(int sck, char *data, int len)
 }
 
 /*****************************************************************************/
-int DEFAULT_CC
+int
 scp_tcp_force_send(int sck, char *data, int len)
 {
     int sent;
     int block;
 
-    LOG_DBG("scp_tcp_force_send()");
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "scp_tcp_force_send()");
     block = scp_lock_fork_critical_section_start();
 
     while (len > 0)
@@ -115,7 +119,7 @@ scp_tcp_force_send(int sck, char *data, int len)
 }
 
 /*****************************************************************************/
-int DEFAULT_CC
+int
 scp_tcp_bind(int sck, char *addr, char *port)
 {
     return g_tcp_bind_address(sck, port, addr);
