@@ -26,6 +26,7 @@
 #include "parse.h"
 #include "os_calls.h"
 #include "defines.h"
+#include "guid.h"
 
 #define CURRENT_MOD_VER 4
 
@@ -123,6 +124,7 @@ struct vnc
                             int box_right, int box_bottom,
                             int x, int y, char *data, int data_len);
     int (*server_reset)(struct vnc *v, int width, int height, int bpp);
+    int (*server_get_channel_count)(struct vnc *v);
     int (*server_query_channel)(struct vnc *v, int index,
                                 char *channel_name,
                                 int *channel_flags);
@@ -132,7 +134,7 @@ struct vnc
                                   int total_data_len, int flags);
     int (*server_bell_trigger)(struct vnc *v);
     int (*server_chansrv_in_use)(struct vnc *v);
-    tintptr server_dumby[100 - 26]; /* align, 100 minus the number of server
+    tintptr server_dumby[100 - 27]; /* align, 100 minus the number of server
                                      functions above */
     /* common */
     tintptr handle; /* pointer to self as long */
@@ -158,8 +160,7 @@ struct vnc
     struct vnc_clipboard_data *vc;
     int delay_ms;
     struct trans *trans;
-    int got_guid;
-    tui8 guid[16];
+    struct guid guid;
     int suppress_output;
     unsigned int enabled_encodings_mask;
     /* Resizeable support */
