@@ -136,8 +136,6 @@ int
 callback(intptr_t id, int msg, intptr_t param1, intptr_t param2,
          intptr_t param3, intptr_t param4);
 int
-xrdp_wm_drdynvc_up(intptr_t id);
-int
 xrdp_wm_delete_all_children(struct xrdp_wm *self);
 int
 xrdp_wm_show_log(struct xrdp_wm *self);
@@ -151,6 +149,8 @@ int
 xrdp_wm_check_wait_objs(struct xrdp_wm *self);
 int
 xrdp_wm_set_login_state(struct xrdp_wm *self, enum wm_login_state login_state);
+void
+xrdp_wm_mod_connect_done(struct xrdp_wm *self, int status);
 
 /* xrdp_process.c */
 struct xrdp_process *
@@ -185,7 +185,7 @@ int
 xrdp_region_get_rect(struct xrdp_region *self, int index,
                      struct xrdp_rect *rect);
 
-/* xrdp_bitmap.c */
+/* xrdp_bitmap_common.c */
 struct xrdp_bitmap *
 xrdp_bitmap_create(int width, int height, int bpp,
                    int type, struct xrdp_wm *wm);
@@ -195,15 +195,9 @@ xrdp_bitmap_create_with_data(int width, int height,
                              struct xrdp_wm *wm);
 void
 xrdp_bitmap_delete(struct xrdp_bitmap *self);
-struct xrdp_bitmap *
-xrdp_bitmap_get_child_by_id(struct xrdp_bitmap *self, int id);
-int
-xrdp_bitmap_set_focus(struct xrdp_bitmap *self, int focused);
 int
 xrdp_bitmap_resize(struct xrdp_bitmap *self, int width, int height);
 int
-xrdp_bitmap_load(struct xrdp_bitmap *self, const char *filename, int *palette);
-int
 xrdp_bitmap_get_pixel(struct xrdp_bitmap *self, int x, int y);
 int
 xrdp_bitmap_set_pixel(struct xrdp_bitmap *self, int x, int y, int pixel);
@@ -211,6 +205,12 @@ int
 xrdp_bitmap_copy_box(struct xrdp_bitmap *self,
                      struct xrdp_bitmap *dest,
                      int x, int y, int cx, int cy);
+
+/* xrdp_bitmap.c */
+struct xrdp_bitmap *
+xrdp_bitmap_get_child_by_id(struct xrdp_bitmap *self, int id);
+int
+xrdp_bitmap_set_focus(struct xrdp_bitmap *self, int focused);
 int
 xrdp_bitmap_hash_crc(struct xrdp_bitmap *self);
 int
@@ -239,6 +239,35 @@ xrdp_bitmap_get_screen_clip(struct xrdp_bitmap *self,
                             struct xrdp_rect *rect,
                             int *dx, int *dy);
 
+/* xrdp_bitmap_load.c */
+/**
+ * Loads a bitmap from a file and (optionally) transforms it
+ *
+ * @param self from rdp_bitmap_create()
+ * @param filename Filename to load
+ * @param[in] palette For 8-bit conversions. Currently unused
+ * @param background Background color for alpha-blending
+ * @param transform Transform to apply to the image after loading
+ * @param twidth target width if transform != XBLT_NONE
+ * @param theight target height if transform != XBLT_NONE
+ * @return 0 for success.
+ *
+ * The background color is only used if the specified image contains
+ * an alpha layer. It is in HCOLOR format, and the bpp must correspond to
+ * the bpp used to create 'self'.
+ *
+ * After a successful call, the bitmap is resized to the image file size.
+ *
+ * If the call is not successful, the bitmap will be in an indeterminate
+ * state and should not be used.
+ */
+int
+xrdp_bitmap_load(struct xrdp_bitmap *self, const char *filename,
+                 const int *palette,
+                 int background,
+                 enum xrdp_bitmap_load_transform transform,
+                 int twidth,
+                 int theight);
 /* xrdp_painter.c */
 struct xrdp_painter *
 xrdp_painter_create(struct xrdp_wm *wm, struct xrdp_session *session);
@@ -391,7 +420,7 @@ struct xrdp_mm *
 xrdp_mm_create(struct xrdp_wm *owner);
 void
 xrdp_mm_delete(struct xrdp_mm *self);
-int
+void
 xrdp_mm_connect(struct xrdp_mm *self);
 int
 xrdp_mm_process_channel_data(struct xrdp_mm *self, tbus param1, tbus param2,
@@ -446,7 +475,7 @@ server_set_pointer_ex(struct xrdp_mod *mod, int x, int y,
 int
 server_palette(struct xrdp_mod *mod, int *palette);
 int
-server_msg(struct xrdp_mod *mod, char *msg, int code);
+server_msg(struct xrdp_mod *mod, const char *msg, int code);
 int
 server_is_term(struct xrdp_mod *mod);
 int
@@ -484,6 +513,8 @@ server_reset(struct xrdp_mod *mod, int width, int height, int bpp);
 int
 is_channel_allowed(struct xrdp_wm *wm, int channel_id);
 int
+server_get_channel_count(struct xrdp_mod *mod);
+int
 server_query_channel(struct xrdp_mod *mod, int index, char *channel_name,
                      int *channel_flags);
 int
