@@ -29,17 +29,7 @@
 #include <painter.h> /* libpainter */
 #endif
 
-#define LLOG_LEVEL 1
-#define LLOGLN(_level, _args) \
-  do \
-  { \
-    if (_level < LLOG_LEVEL) \
-    { \
-        g_write("xrdp:xrdp_painter [%10.10u]: ", g_time3()); \
-        g_writeln _args ; \
-    } \
-  } \
-  while (0)
+
 
 #if defined(XRDP_PAINTER)
 
@@ -72,8 +62,8 @@ xrdp_painter_add_dirty_rect(struct xrdp_painter *self, int x, int y,
     rect.right = x + cx;
     rect.bottom = y + cy;
     xrdp_region_add_rect(self->dirty_region, &rect);
-    LLOGLN(10, ("xrdp_painter_add_dirty_rect: x %d y %d cx %d cy %d",
-           x, y, cx, cy));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_add_dirty_rect: x %d y %d cx %d cy %d",
+              x, y, cx, cy);
     return 0;
 }
 
@@ -93,7 +83,7 @@ xrdp_painter_send_dirty(struct xrdp_painter *self)
     char *dst;
     struct xrdp_rect rect;
 
-    LLOGLN(10, ("xrdp_painter_send_dirty:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_send_dirty:");
 
     bpp = self->wm->screen->bpp;
     Bpp = (bpp + 7) / 8;
@@ -123,8 +113,8 @@ xrdp_painter_send_dirty(struct xrdp_painter *self)
             src += self->wm->screen->line_size;
             dst += cx * Bpp;
         }
-        LLOGLN(10, ("xrdp_painter_send_dirty: x %d y %d cx %d cy %d",
-               rect.left, rect.top, cx, cy));
+        LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_send_dirty: x %d y %d cx %d cy %d",
+                  rect.left, rect.top, cx, cy);
         libxrdp_send_bitmap(self->session, cx, cy, bpp,
                             ldata, rect.left, rect.top, cx, cy);
         g_free(ldata);
@@ -147,7 +137,7 @@ xrdp_painter_create(struct xrdp_wm *wm, struct xrdp_session *session)
 {
     struct xrdp_painter *self;
 
-    LLOGLN(10, ("xrdp_painter_create:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_create:");
     self = (struct xrdp_painter *)g_malloc(sizeof(struct xrdp_painter), 1);
     self->wm = wm;
     self->session = session;
@@ -161,11 +151,11 @@ xrdp_painter_create(struct xrdp_wm *wm, struct xrdp_session *session)
         if (painter_create(&(self->painter)) != PT_ERROR_NONE)
         {
             self->painter = 0;
-            LLOGLN(0, ("xrdp_painter_create: painter_create failed"));
+            LOG_DEVEL(LOG_LEVEL_WARNING, "xrdp_painter_create: painter_create failed");
         }
         else
         {
-            LLOGLN(10, ("xrdp_painter_create: painter_create success"));
+            LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_create: painter_create success");
         }
         self->dirty_region = xrdp_region_create(wm);
 #endif
@@ -178,7 +168,7 @@ xrdp_painter_create(struct xrdp_wm *wm, struct xrdp_session *session)
 void
 xrdp_painter_delete(struct xrdp_painter *self)
 {
-    LLOGLN(10, ("xrdp_painter_delete:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_delete:");
     if (self == 0)
     {
         return;
@@ -200,7 +190,7 @@ wm_painter_set_target(struct xrdp_painter *self)
     int index;
     struct list *del_list;
 
-    LLOGLN(10, ("wm_painter_set_target:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "wm_painter_set_target:");
 
     if (self->painter != 0)
     {
@@ -240,7 +230,7 @@ wm_painter_set_target(struct xrdp_painter *self)
     }
     else
     {
-        g_writeln("xrdp_painter_begin_update: bad target_surface");
+        LOG(LOG_LEVEL_WARNING, "xrdp_painter_begin_update: bad target_surface");
     }
 
     return 0;
@@ -250,7 +240,7 @@ wm_painter_set_target(struct xrdp_painter *self)
 int
 xrdp_painter_begin_update(struct xrdp_painter *self)
 {
-    LLOGLN(10, ("xrdp_painter_begin_update:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_begin_update:");
     if (self == 0)
     {
         return 0;
@@ -272,7 +262,7 @@ xrdp_painter_begin_update(struct xrdp_painter *self)
 int
 xrdp_painter_end_update(struct xrdp_painter *self)
 {
-    LLOGLN(10, ("xrdp_painter_end_update:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_end_update:");
     if (self == 0)
     {
         return 0;
@@ -445,7 +435,7 @@ xrdp_painter_text_width(struct xrdp_painter *self, const char *text)
     struct xrdp_font_char *font_item;
     twchar *wstr;
 
-    LLOGLN(10, ("xrdp_painter_text_width:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_text_width:");
     xrdp_painter_font_needed(self);
 
     if (self->font == 0)
@@ -483,7 +473,7 @@ xrdp_painter_text_height(struct xrdp_painter *self, const char *text)
     struct xrdp_font_char *font_item;
     twchar *wstr;
 
-    LLOGLN(10, ("xrdp_painter_text_height:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_text_height:");
     xrdp_painter_font_needed(self);
 
     if (self->font == 0)
@@ -519,7 +509,7 @@ xrdp_painter_setup_brush(struct xrdp_painter *self,
 {
     int cache_id;
 
-    LLOGLN(10, ("xrdp_painter_setup_brush:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_setup_brush:");
 
     if (self->painter != 0)
     {
@@ -591,7 +581,7 @@ xrdp_painter_fill_rect(struct xrdp_painter *self,
     int dy;
     int rop;
 
-    LLOGLN(10, ("xrdp_painter_fill_rect:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_fill_rect:");
 
     if (self == 0)
     {
@@ -608,10 +598,10 @@ xrdp_painter_fill_rect(struct xrdp_painter *self,
         struct xrdp_bitmap *ldst;
         struct painter_bitmap pat;
 
-        LLOGLN(10, ("xrdp_painter_fill_rect: dst->type %d", dst->type));
+        LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_fill_rect: dst->type %d", dst->type);
         if (dst->type != WND_TYPE_OFFSCREEN)
         {
-            LLOGLN(10, ("xrdp_painter_fill_rect: using painter"));
+            LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_fill_rect: using painter");
 
             ldst = self->wm->screen;
 
@@ -622,9 +612,9 @@ xrdp_painter_fill_rect(struct xrdp_painter *self,
             dst_pb.height = ldst->height;
             dst_pb.data = ldst->data;
 
-            LLOGLN(10, ("xrdp_painter_fill_rect: ldst->width %d ldst->height %d "
-                       "dst->data %p self->fg_color %d",
-                       ldst->width, ldst->height, ldst->data, self->fg_color));
+            LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_fill_rect: ldst->width %d ldst->height %d "
+                      "dst->data %p self->fg_color %d",
+                      ldst->width, ldst->height, ldst->data, self->fg_color);
 
             xrdp_bitmap_get_screen_clip(dst, self, &clip_rect, &dx, &dy);
             region = xrdp_region_create(self->wm);
@@ -833,7 +823,7 @@ xrdp_painter_draw_text(struct xrdp_painter *self,
     struct xrdp_font_char *font_item;
     twchar *wstr;
 
-    LLOGLN(10, ("xrdp_painter_draw_text:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_draw_text:");
 
     if (self == 0)
     {
@@ -1026,7 +1016,7 @@ xrdp_painter_draw_text2(struct xrdp_painter *self,
     int dx;
     int dy;
 
-    LLOGLN(0, ("xrdp_painter_draw_text2:"));
+    LOG_DEVEL(LOG_LEVEL_INFO, "xrdp_painter_draw_text2:");
 
     if (self == 0)
     {
@@ -1128,7 +1118,7 @@ xrdp_painter_copy(struct xrdp_painter *self,
     int index;
     struct list *del_list;
 
-    LLOGLN(10, ("xrdp_painter_copy:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_copy:");
 
     if (self == 0 || src == 0 || dst == 0)
     {
@@ -1142,12 +1132,12 @@ xrdp_painter_copy(struct xrdp_painter *self,
         struct painter_bitmap dst_pb;
         struct xrdp_bitmap *ldst;
 
-        LLOGLN(10, ("xrdp_painter_copy: src->type %d dst->type %d", src->type, dst->type));
-        LLOGLN(10, ("xrdp_painter_copy: self->rop 0x%2.2x", self->rop));
+        LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_copy: src->type %d dst->type %d", src->type, dst->type);
+        LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_copy: self->rop 0x%2.2x", self->rop);
 
         if (dst->type != WND_TYPE_OFFSCREEN)
         {
-            LLOGLN(10, ("xrdp_painter_copy: using painter"));
+            LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_copy: using painter");
             ldst = self->wm->screen;
 
             g_memset(&dst_pb, 0, sizeof(dst_pb));
@@ -1181,8 +1171,8 @@ xrdp_painter_copy(struct xrdp_painter *self,
                                      draw_rect.left, draw_rect.top,
                                      draw_rect.right - draw_rect.left,
                                      draw_rect.bottom - draw_rect.top);
-                    LLOGLN(10, ("  x %d y %d cx %d cy %d srcx %d srcy %d",
-                           x, y, cx, cy, srcx, srcy));
+                    LOG_DEVEL(LOG_LEVEL_DEBUG, "  x %d y %d cx %d cy %d srcx %d srcy %d",
+                              x, y, cx, cy, srcx, srcy);
                     painter_copy(self->painter, &dst_pb, x, y, cx, cy,
                                  &src_pb, srcx, srcy);
                     xrdp_painter_add_dirty_rect(self, x, y, cx, cy,
@@ -1241,20 +1231,20 @@ xrdp_painter_copy(struct xrdp_painter *self,
     }
     else if (src->type == WND_TYPE_OFFSCREEN)
     {
-        //g_writeln("xrdp_painter_copy: todo");
+        LOG(LOG_LEVEL_DEBUG, "xrdp_painter_copy: todo");
 
         xrdp_bitmap_get_screen_clip(dst, self, &clip_rect, &dx, &dy);
         region = xrdp_region_create(self->wm);
 
         if (dst->type != WND_TYPE_OFFSCREEN)
         {
-            //g_writeln("off screen to screen");
+            LOG(LOG_LEVEL_DEBUG, "off screen to screen");
             xrdp_wm_get_vis_region(self->wm, dst, x, y, cx, cy,
                                    region, self->clip_children);
         }
         else
         {
-            //g_writeln("off screen to off screen");
+            LOG(LOG_LEVEL_DEBUG, "off screen to off screen");
             xrdp_region_add_rect(region, &clip_rect);
         }
 
@@ -1267,7 +1257,7 @@ xrdp_painter_copy(struct xrdp_painter *self,
 
         if (src->tab_stop == 0)
         {
-            g_writeln("xrdp_painter_copy: warning src not created");
+            LOG(LOG_LEVEL_WARNING, "xrdp_painter_copy: warning src not created");
             del_list = self->wm->cache->xrdp_os_del_list;
             index = list_index_of(del_list, cache_idx);
             list_remove_item(del_list, index);
@@ -1376,15 +1366,15 @@ xrdp_painter_copy(struct xrdp_painter *self,
 
 /*****************************************************************************/
 int
-xrdp_painter_composite(struct xrdp_painter* self,
-                       struct xrdp_bitmap* src,
+xrdp_painter_composite(struct xrdp_painter *self,
+                       struct xrdp_bitmap *src,
                        int srcformat,
                        int srcwidth,
                        int srcrepeat,
-                       struct xrdp_bitmap* dst,
-                       int* srctransform,
+                       struct xrdp_bitmap *dst,
+                       int *srctransform,
                        int mskflags,
-                       struct xrdp_bitmap* msk,
+                       struct xrdp_bitmap *msk,
                        int mskformat, int mskwidth, int mskrepeat, int op,
                        int srcx, int srcy, int mskx, int msky,
                        int dstx, int dsty, int width, int height, int dstformat)
@@ -1393,14 +1383,14 @@ xrdp_painter_composite(struct xrdp_painter* self,
     struct xrdp_rect draw_rect;
     struct xrdp_rect rect1;
     struct xrdp_rect rect2;
-    struct xrdp_region* region;
+    struct xrdp_region *region;
     int k;
     int dx;
     int dy;
     int cache_srcidx;
     int cache_mskidx;
 
-    LLOGLN(0, ("xrdp_painter_composite:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_composite:");
 
     if (self == 0 || src == 0 || dst == 0)
     {
@@ -1474,7 +1464,7 @@ xrdp_painter_line(struct xrdp_painter *self,
     int dy;
     int rop;
 
-    LLOGLN(10, ("xrdp_painter_line:"));
+    LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_line:");
     if (self == 0)
     {
         return 0;
@@ -1489,12 +1479,12 @@ xrdp_painter_line(struct xrdp_painter *self,
         struct painter_bitmap dst_pb;
         struct xrdp_bitmap *ldst;
 
-        LLOGLN(10, ("xrdp_painter_line: dst->type %d", dst->type));
-        LLOGLN(10, ("xrdp_painter_line: self->rop 0x%2.2x", self->rop));
+        LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_line: dst->type %d", dst->type);
+        LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_line: self->rop 0x%2.2x", self->rop);
 
         if (dst->type != WND_TYPE_OFFSCREEN)
         {
-            LLOGLN(10, ("xrdp_painter_line: using painter"));
+            LOG_DEVEL(LOG_LEVEL_DEBUG, "xrdp_painter_line: using painter");
             ldst = self->wm->screen;
 
             g_memset(&dst_pb, 0, sizeof(dst_pb));
